@@ -72,6 +72,7 @@ class TwelveData():
                 self.getHistory()
             else:
                 return self.history
+                
         except Exception as e:
             print(e)
             print("wait for 1min:5sec to try again...")
@@ -79,6 +80,9 @@ class TwelveData():
             time.sleep(65)
             self.getHistory()
 
+        ### Drop Dublicates
+        self.history = self.history.drop_duplicates(keep = 'first')
+
         return self.history
 
             
